==> fastor_app_ui_widget-0.0.1.tar.gz: lib/resource/boarder/BoarderHelper.dart <==
import 'package:flutter/material.dart';

import 'package:fastor_app_ui_widget/resource/ds/DesignSystemColor.dart';
import 'package:fastor_app_ui_widget/resource/ds/DesignSystemDimen.dart';


import 'BaseBoarderHelper.dart';

class BoarderHelper extends BaseBoarderHelper{

  static BoxDecoration cardView(  {
    double? radiusSize ,
    Color? colorBackground ,
    Color? colorLine ,
} ) {


    //set default
    radiusSize ??= DSDimen.ds_size_corner_level_2;
    colorBackground ??= DSColor.cardview_background_color  ;
    colorLine ??= DSColor.cardview_boarderLine  ;

    var dec_container_radius = BoxDecoration(
        border: Border.all(color: colorLine ) ,
        borderRadius: BorderRadius.circular(radiusSize!) ,
        color: colorBackground                                                          //background color
    );

    return dec_container_radius;
  }

  static BoxDecoration cardViewShadow( {
    double? radiusSize  ,
    Color? colorBackground,
    double? widthLine = 1 ,
    Color? colorLine ,
  }) {

    //default
    radiusSize ??= DSDimen.ds_size_corner_level_2;
    colorBackground ??= DSColor.cardview_background_color;
    colorLine ??= DSColor.cardview_boarderLine;

    return BaseBoarderHelper.circle(radiusSize: radiusSize!,
        colorBackground:  colorBackground,
        widthLine: widthLine!,
        colorLine: colorLine);
  }


  static BoxDecoration bottom_line( {
    double? radiusSize  ,
    Color? colorBackground,
    double? widthLine = 1 ,
    Color? colorLine ,
  }) {

    //default
    radiusSize ??= DSDimen.ds_size_corner_level_2;
    colorBackground ??= DSColor.cardview_background_color;
    colorLine ??= DSColor.cardview_boarderLine;

    return BaseBoarderHelper.bottom_line(radiusSize: radiusSize!,
        colorBackground:  colorBackground,
        widthLine: widthLine!,
        colorLine: colorLine);
  }


  static BoxDecoration top_line( {
    double radiusSize = 10 ,
    Color colorBackground = Colors.green,
    double widthLine = 5 ,
    Color colorLine = Colors.red,
  }) {
    return BaseBoarderHelper.top_line(radiusSize: radiusSize, colorBackground:  colorBackground, widthLine: widthLine, colorLine: colorLine);
  }

  static BoxDecoration button_large({
    double radiusSize = 10,
    Color colorBackground = Colors.green,
    double widthLine = 5,
    Color colorLine = Colors.red,
  }) {
    return BaseBoarderHelper.circle(
        radiusSize: radiusSize,
        colorBackground: colorBackground,
        widthLine: widthLine,
        colorLine: colorLine);
  }



  static BoxDecoration test( {
    double radiusSize = 0 ,
    Color colorBackground = Colors.green,
    double widthLine = 0 ,
    Color colorLine = Colors.red,
  }) {
    return BaseBoarderHelper.top_line(radiusSize: radiusSize, colorBackground:  colorBackground, widthLine: widthLine, colorLine: colorLine);
  }

  static rounded({
    double? radiusSize ,
    Color? colorBackground = Colors.transparent,
    Color? colorLine ,}) {

    //set default
    radiusSize ??= DSDimen.ds_size_corner_level_2;
    colorBackground ??= DSColor.cardview_background_color  ;
    colorLine ??= DSColor.cardview_boarderLine  ;



    var dec_container_radius = BoxDecoration(
        border: Border.all(color: colorLine ) ,
        borderRadius: BorderRadius.circular(radiusSize!) ,
        color: colorBackground                                                          //background color
    );
    return dec_container_radius;

    // var widthLine = 1.0;
    // var rounded = RoundedRectangleBorder(
    //   borderRadius: BorderRadius.circular(radiusSize) ,
    //   side: BorderSide(
    //     color: colorLine,
    //     width: widthLine,
    //   ),
    // );
    // return rounded;
  }


  static box({
    Color? colorBackground = Colors.transparent,
    Color? colorLine ,}) {

    //set default
    colorBackground ??= DSColor.cardview_background_color  ;
    colorLine ??= DSColor.cardview_boarderLine  ;

    var box = BoxDecoration(
        border: Border.all(color: colorLine ) ,

        color: colorBackground                                                          //background color
    );
    return box;
  }


}

==> fastor_app_ui_widget-0.0.3.tar.gz: lib/resource/boarder/BoarderHelper.dart <==
import 'package:flutter/material.dart';

import 'package:fastor_app_ui_widget/resource/ds/DesignSystemColor.dart';
import 'package:fastor_app_ui_widget/resource/ds/DesignSystemDimen.dart';


import 'BaseBoarderHelper.dart';

class BoarderHelper extends BaseBoarderHelper{

  static BoxDecoration cardView(  {
    double? radiusSize ,
    Color? colorBackground ,
    Color? colorLine ,
} ) {


    //set default
    radiusSize ??= DSDimen.ds_size_corner_level_2;
    colorBackground ??= DSColor.cardview_background_color  ;
    colorLine ??= DSColor.cardview_boarderLine  ;

    var dec_container_radius = BoxDecoration(
        border: Border.all(color: colorLine ) ,
        borderRadius: BorderRadius.circular(radiusSize  ?? 0 ) ,
        color: colorBackground                                                          //background color
    );

    return dec_container_radius;
  }

  static BoxDecoration cardViewShadow( {
    double? radiusSize  ,
    Color? colorBackground,
    double? widthLine = 1 ,
    Color? colorLine ,
  }) {

    //default
    radiusSize ??= DSDimen.ds_size_corner_level_2;
    colorBackground ??= DSColor.cardview_background_color;
    colorLine ??= DSColor.cardview_boarderLine;

    return BaseBoarderHelper.circle(radiusSize: radiusSize  ?? 0,
        colorBackground:  colorBackground,
        widthLine: widthLine!,
        colorLine: colorLine);
  }


  static BoxDecoration bottom_line( {
    double? radiusSize  ,
    Color? colorBackground,
    double? widthLine = 1 ,
    Color? colorLine ,
  }) {

    //default
    radiusSize ??= DSDimen.ds_size_corner_level_2;
    colorBackground ??= DSColor.cardview_background_color;
    colorLine ??= DSColor.cardview_boarderLine;

    return BaseBoarderHelper.bottom_line(radiusSize: radiusSize  ?? 0,
        colorBackground:  colorBackground,
        widthLine: widthLine!,
        colorLine: colorLine);
  }


  static BoxDecoration top_line( {
    double radiusSize = 10 ,
    Color colorBackground = Colors.green,
    double widthLine = 5 ,
    Color colorLine = Colors.red,
  }) {
    return BaseBoarderHelper.top_line(radiusSize: radiusSize,
        colorBackground:  colorBackground, widthLine: widthLine, colorLine: colorLine);
  }

  static BoxDecoration button_large({
    double radiusSize = 10,
    Color colorBackground = Colors.green,
    double widthLine = 5,
    Color colorLine = Colors.red,
  }) {
    return BaseBoarderHelper.circle(
        radiusSize: radiusSize,
        colorBackground: colorBackground,
        widthLine: widthLine,
        colorLine: colorLine);
  }



  static BoxDecoration test( {
    double radiusSize = 0 ,
    Color colorBackground = Colors.green,
    double widthLine = 0 ,
    Color colorLine = Colors.red,
  }) {
    return BaseBoarderHelper.top_line(radiusSize: radiusSize, colorBackground:  colorBackground, widthLine: widthLine, colorLine: colorLine);
  }

  static rounded({
    double? radiusSize ,
    Color? colorBackground = Colors.transparent,
    Color? colorLine ,}) {

    //set default
    radiusSize ??= DSDimen.ds_size_corner_level_2;
    colorBackground ??= DSColor.cardview_background_color  ;
    colorLine ??= DSColor.cardview_boarderLine  ;



    var dec_container_radius = BoxDecoration(
        border: Border.all(color: colorLine ) ,
        borderRadius: BorderRadius.circular(radiusSize ?? 0 ) ,
        color: colorBackground                                                          //background color
    );
    return dec_container_radius;

    // var widthLine = 1.0;
    // var rounded = RoundedRectangleBorder(
    //   borderRadius: BorderRadius.circular(radiusSize) ,
    //   side: BorderSide(
    //     color: colorLine,
    //     width: widthLine,
    //   ),
    // );
    // return rounded;
  }


  static box({
    Color? colorBackground = Colors.transparent,
    Color? colorLine ,}) {

    //set default
    colorBackground ??= DSColor.cardview_background_color  ;
    colorLine ??= DSColor.cardview_boarderLine  ;

    var box = BoxDecoration(
        border: Border.all(color: colorLine ) ,

        color: colorBackground                                                          //background color
    );
    return box;
  }


}
